# Who Am I? | من أنا؟

🇸🇾 **Syrian Developer**  
🇸🇾 **مطوّر سوري**

Personal developer profile for quick introduction in both English and Arabic.

## Who Am I?

- **Name:** Ahmed Muhammad
- **Telegram:** [@K_6_3](https://t.me/K_6_3)
- **Role:** Student / Programming Hobbyist
- **Focus Areas:** I am passionate about technology in general, with a strong interest in AI news and programming.
- **Currently Building:** I am currently a high school student and learning by building small projects.
- **Location:** Syria 🇸🇾
- **Contact Email:** 0a1h2m3e4d5123321@gmail.com
- **Telegram  group for the project:**  [@MudabbirAi](https://t.me/MudabbirAi)


## من أنا؟

- **الاسم:** أحمد محمد
- **التليجرام:** [K_6_3@](https://t.me/K_6_3)
- **الدور:** طالب / هاوي برمجة
- **مجالات التركيز:** لدي حب للتقنية بشكل عام، وأهتم بأخبار الذكاء الاصطناعي والبرمجة.
- **أعمل حاليًا على:** طالب ثانوي
- **الموقع:** سوريا 🇸🇾
- **البريد الإلكتروني:** 0a1h2m3e4d5123321@gmail.com
- **مجموعة تليجرام للمشروع**  [MudabbirAi@](https://t.me/MudabbirAi)
